@@ -1,5 +1,6 @@
 /*
- * LALDetCharVCSInfo.h - LALDetChar VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALDetCharVCSInfo.h - LALDetChar VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALDETCHAR_NAME "LALDetChar"
-#define LALDETCHAR_VCS_ID "b6ccf6e5998509725e3676332a7bb352509de687"
-#define LALDETCHAR_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALDETCHAR_VCS_ID "b2ecf41f30505146ab6d0ec98bfc09f13bca58bc"
+#define LALDETCHAR_VCS_DATE "2017-02-6 18:16:00 +0000"
 #define LALDETCHAR_VCS_BRANCH "None"
-#define LALDETCHAR_VCS_TAG "laldetchar-v0.3.4"
+#define LALDETCHAR_VCS_TAG "laldetchar-v0.3.5"
 #define LALDETCHAR_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALDETCHAR_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALDETCHAR_VCS_CLEAN "CLEAN"
 #define LALDETCHAR_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALDETCHAR_VCS_IDENT_ID "$" "LALDetCharId: b6ccf6e5998509725e3676332a7bb352509de687 " "$"
-#define LALDETCHAR_VCS_IDENT_DATE "$" "LALDetCharDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALDETCHAR_VCS_IDENT_BRANCH "$" "LALDetCharBranch: None " "$"
-#define LALDETCHAR_VCS_IDENT_TAG "$" "LALDetCharTag: laldetchar-v0.3.4 " "$"
-#define LALDETCHAR_VCS_IDENT_AUTHOR "$" "LALDetCharAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALDETCHAR_VCS_IDENT_COMMITTER "$" "LALDetCharCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALDETCHAR_VCS_IDENT_STATUS "$" "LALDetCharStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalDetCharVCSInfoHeader = { \
-  LALDETCHAR_NAME, \
-  LALDETCHAR_VERSION, \
-  LALDETCHAR_VCS_ID, \
-  LALDETCHAR_VCS_DATE, \
-  LALDETCHAR_VCS_BRANCH, \
-  LALDETCHAR_VCS_TAG, \
-  LALDETCHAR_VCS_AUTHOR, \
-  LALDETCHAR_VCS_COMMITTER, \
-  LALDETCHAR_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALDETCHAR_VCS_LINK_CHECK LALDETCHAR_CLEAN_b2ecf41f30505146ab6d0ec98bfc09f13bca58bc_VCS_HEADER_LIBRARY_MISMATCH
+void LALDETCHAR_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalDetCharVCSInfoHeader = { \
 #endif /* _LALDETCHARVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
